package canchasadmon.dao;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Scanner;
import java.util.logging.Level;
import java.util.logging.Logger;

public class ManejadorSecuenciaDAO {

	private ManejadorSecuenciaDAO(){}
    
	private static class Holder {
		private static final ManejadorSecuenciaDAO INSTANCE = new ManejadorSecuenciaDAO();
    }

    public static ManejadorSecuenciaDAO getInstance() {
        return Holder.INSTANCE;
    }
	
  
    public synchronized Long nextValue(String ficheroSecuencia) {
          
        File fichero =  new File(ficheroSecuencia);
        Long valorActual = getValorActual(fichero);
      
        guardarSiguienteValor(valorActual, fichero);
                
        return valorActual;
        
    }
   
    private String formatearValor(Long valor) {

        return String.format("%010d", valor);
    
    }
    
    private synchronized void guardarSiguienteValor(Long valorActual, File fichero) {      
        
        PrintWriter pw = null;       
        
        try {
            
            pw = new PrintWriter(new FileWriter(fichero));
            pw.write(formatearValor(valorActual+1));
            
        }catch (IOException ex) {
            Logger.getLogger(ManejadorSecuenciaDAO.class.getName()).log(Level.SEVERE, null, ex);
        }finally {
            if(null != pw) {
                pw.close();
            }
        }

    }
    
    private synchronized Long getValorActual(File fichero) {
    
        Scanner scanner = null;
        Long valorActual = null;
        //Leer el numero de secuencia
        
        try {
 
            scanner = new Scanner(fichero);
            String line = scanner.nextLine();            
             
            valorActual = Long.parseLong(line);
            
            
        } catch (FileNotFoundException ex) {
            
            Logger.getLogger(ManejadorSecuenciaDAO.class.getName()).log(Level.SEVERE, null, ex);
            
        }finally {
        
            if(null!=scanner) {
                scanner.close();
            }
        }
       
        return valorActual;
        
    }
	
}
