package canchasadmon.dao;

import canchasadmon.common.TipoUsuario;
import canchasadmon.vo.UsuarioVO;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.ArrayList;
import java.util.List;

public class UsuarioDAOImpl implements UsuarioDAO {

	private final static List<UsuarioVO> USUARIOS = new ArrayList<UsuarioVO>();

	private UsuarioDAOImpl() {

		leerArchivo();

	}

	private static class Holder {
		private static final UsuarioDAO INSTANCE = new UsuarioDAOImpl();
	}

	public static UsuarioDAO getInstance() {

		return Holder.INSTANCE;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see dao.UsuarioDAO#listar()
	 */
	@Override
	public synchronized List<UsuarioVO> listar() {

		return new ArrayList<UsuarioVO>(USUARIOS);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see dao.UsuarioDAO#agregar(vo.UsuarioVO)
	 */
	@Override
	public synchronized UsuarioVO agregar(UsuarioVO usuario) {

		ManejadorSecuenciaDAO manejadorSecuenciaDAO = ManejadorSecuenciaDAO.getInstance();
		Long id = manejadorSecuenciaDAO.nextValue(USUARIO_SEQ);
		usuario.setId(id);

		USUARIOS.add(usuario);

		guardarArchivo();

		return usuario;

	}

        @Override
	public synchronized UsuarioVO actualizar(UsuarioVO usuario) {

		UsuarioVO usuarioVO = null;

		for (int i = 0; i < USUARIOS.size(); i++) {

			usuarioVO = USUARIOS.get(i);

			if (usuarioVO.getId().longValue() == usuario.getId().longValue()) {

				usuarioVO.setNombre(usuario.getNombre());
                                usuarioVO.setApellidoPaterno(usuario.getApellidoPaterno());
                                usuarioVO.setApelidoMaterno(usuario.getApelidoMaterno());
                                usuarioVO.setContrasenya(usuario.getContrasenya());
                                usuarioVO.setNombreUsuario(usuario.getNombreUsuario());
                                usuarioVO.setTipoUsuario(usuario.getTipoUsuario());
                                usuarioVO.setNombreUsuario(usuario.getNombreUsuario());

                                usuario.setFechaBaja(usuarioVO.getFechaBaja());
                                usuario.setFechaRegistro(usuarioVO.getFechaRegistro());
                                
				guardarArchivo();

			}

		}

		return usuario;

	}
        
	/*
	 * (non-Javadoc)
	 * 
	 * @see dao.UsuarioDAO#eliminar(java.lang.String, java.lang.String)
	 */
	@Override
	public synchronized boolean eliminar(String nombre, String nombreUsuario) {

		UsuarioVO usuarioVO = null;

		for (int i = 0; i < USUARIOS.size(); i++) {

			usuarioVO = USUARIOS.get(i);

			if (usuarioVO.getNombreUsuario().equals(nombreUsuario) && usuarioVO.getNombre().equals(nombre)) {

				USUARIOS.remove(i);

				guardarArchivo();

				return true;

			}

		}

		return false;

	}
                      
	@SuppressWarnings("rawtypes")
	private void guardarArchivo() {

		FileOutputStream fout = null;
		ObjectOutputStream oos = null;

		try {

			fout = new FileOutputStream(USUARIO_FILE);
			oos = new ObjectOutputStream(fout);

			oos.writeObject((ArrayList) USUARIOS);

		} catch (Exception ex) {

			ex.printStackTrace();

		} finally {

			if (null != fout) {
				try {
					fout.close();
				} catch (IOException e) {
					fout = null;
				}
			}
			if (null != oos) {
				try {
					oos.close();
				} catch (IOException e) {
					oos= null;
				}
			}

		}

	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void leerArchivo() {

		FileInputStream fin = null;
		ObjectInputStream ois = null;
		
		try {

			USUARIOS.clear();

			fin = new FileInputStream(USUARIO_FILE);
			ois = new ObjectInputStream(fin);
			
			USUARIOS.addAll((ArrayList) ois.readObject());

			ois.close();

		} catch (Exception ex) {

			ex.printStackTrace();

		}finally {

			if (null != fin) {
				try {
					fin.close();
				} catch (IOException e) {
					fin = null;
				}
			}
			if (null != ois) {
				try {
					ois.close();
				} catch (IOException e) {
					ois= null;
				}
			}

		}

	}

}
